hpmcm package
=============


Matchers
--------

.. toctree::
   :maxdepth: 4

   hpmcm.match
   hpmcm.shear_match
   hpmcm.wcs_match
   

Input/Output Table Formats
--------------------------

.. toctree::
   :maxdepth: 4

   hpmcm.input_tables
   hpmcm.output_tables
   hpmcm.table

 
Internal Data Structures
------------------------

.. toctree::
   :maxdepth: 4

   hpmcm.cell
   hpmcm.cluster
   hpmcm.object
   hpmcm.shear_data
   hpmcm.footprint


Utility Functions
-----------------

.. toctree::
   :maxdepth: 4

   hpmcm.classify
   hpmcm.match_utils
   hpmcm.package_utils
   hpmcm.shear_utils
   hpmcm.utils
   hpmcm.viz_utils

